Bassic functionalities to work with images in Funcnodes

Most important is the extendable "ImageFormat" class, which allows for automatic rendering and conversion of different image formats if they are implemented. Each should have their own respective package, e.g. funcnodes_opencv as this is only the basis for them to prevent reimplementations.
